Links
-----


Presentations
=============

Yosemite
~~~~~~~~

.. raw:: html

  <iframe src="https://docs.google.com/presentation/d/e/2PACX-1vSZCvLwMqgGP5osy5w_5P45TvF6adkyem-Zg4UMndkKp01rWyVPY2eUYZmvr_odkPDJrtyPegUjZYwM/embed?start=false&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>

.. raw:: html
  
  <iframe width="560" height="315" src="https://www.youtube.com/embed/1cZu4kZ2ufQ" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>  
  
Model Templates
~~~~~~~~~~~~~~~

.. raw:: html

  <iframe src="https://docs.google.com/presentation/d/e/2PACX-1vQBboArJfptgWfDO5HGZ8_AXbv1ExygRXL-9wVDpLfBnC2xw1n_igdUsigpV2W6MtO-Grd1gj7wfCpH/embed?start=false&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>


Environmental genomics use case
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. raw:: html

  <iframe src="https://docs.google.com/presentation/d/e/2PACX-1vSfet-ZsaHuWl9VMCH0k7I_mESsyWGpLg9_Tofs9TyC8egJIRCkPPe88smG57l2dmXsARTkB93NgE-e/embed?start=false&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
